import React, { useState, ReactElement, useEffect } from 'react';
import {
  View,
  Text,
  TouchableOpacity,
  ViewStyle,
  TextStyle,
  ScrollView,
} from 'react-native';
import { Dialog } from '@rneui/themed';
import PropTypes from 'prop-types';

const search = (keyName, myArray) => {
  return myArray.some((val) => val === keyName);
};

const Stepper = (props) => {
  const {
    active,
    data,
    content,
    onBack,
    onNext,
    onFinish,
    wrapperStyle,
    stepStyle,
    stepTextStyle,
    buttonStyle,
    buttonTextStyle,
    showButton = true,
  } = props;
  const [step, setStep] = useState([0]);
  const pushData = (val) => {
    setStep((prev) => [...prev, val]);
  };

  const [showDialog, setShowDialog] = useState(false);
  const [message, setMessage] = useState('');

  const removeData = () => {
    setStep((prev) => {
      prev.pop();
      return prev;
    });
  };

  useEffect(() => {
    if (step[step.length - 1] > active) {
      removeData();
    } else {
      pushData(active);
    }
  }, [active]);

  return (
    <View style={wrapperStyle}>
      <View
        style={{
          flexDirection: 'row',
          justifyContent: 'center',
          alignItems: 'center',
        }}
      >
        {content.map((_, i) => {
          return (
            <React.Fragment key={i}>
              {i !== 0 && (
                <View
                  style={{
                    flex: 1,
                    height: 1,
                    backgroundColor: 'grey',
                    opacity: 1,
                    marginHorizontal: 10,
                  }}
                />
              )}
              <View
                style={[
                  {
                    backgroundColor: '#1976d2',
                    width: 30,
                    height: 30,
                    borderRadius: 30,
                    justifyContent: 'center',
                    alignItems: 'center',
                    opacity: search(i, step) ? 1 : 0.3,
                  },
                  stepStyle,
                ]}
              >
                {search(i, step) ? (
                  <Text
                    style={[
                      {
                        color: 'white',
                      },
                      stepTextStyle,
                    ]}
                  >
                    &#10003;
                  </Text>
                ) : (
                  <Text
                    style={[
                      {
                        color: 'white',
                      },
                      stepTextStyle,
                    ]}
                  >
                    {i + 1}
                  </Text>
                )}
              </View>
            </React.Fragment>
          );
        })}
      </View>
      <ScrollView showsVerticalScrollIndicator={false}>
        {content[active]}
      </ScrollView>
      {showButton && (
        <View
          style={{
            flexDirection: 'row',
            justifyContent: 'space-evenly',
            alignItems: 'center',
          }}
        >
          {active !== 0 && content.length - 1 !== active && (
            <TouchableOpacity
              style={[
                {
                  padding: 10,
                  borderRadius: 4,
                  alignSelf: 'flex-start',
                  marginRight: 10,
                },
                buttonStyle,
                {
                  backgroundColor: '#a1a1a1',
                },
              ]}
              onPress={() => {
                removeData();
                onBack();
              }}
            >
              <Text style={[{ color: 'white' }, buttonTextStyle]}>
                Regresar
              </Text>
            </TouchableOpacity>
          )}
          {content.length - 1 !== active && (
            <TouchableOpacity
              style={[
                {
                  padding: 10,
                  borderRadius: 4,
                  backgroundColor: '#1976d2',
                  alignSelf: 'flex-start',
                  marginRight: 10,
                },
                buttonStyle,
              ]}
              onPress={() => {
                console.log(active);
                if (active === 0) {
                  if (data.weight === '' || data.cn === '') {
                    setShowDialog(true);
                    setMessage('Por favor llene todos los campos');
                    return;
                  }

                  if(data.unit === 'lb'){
                    if (data.weight < 100 || data.weight > 1000) {
                      setShowDialog(true);
                      setMessage('El peso debe estar entre 100 y 1000 libras');
                      return;
                    }
                  }
                  else{
                    if (data.weight < 45 || data.weight > 450) {
                      setShowDialog(true);
                      setMessage('El peso debe estar entre 45 y 450 kilogramos');
                      return;
                    }
                  }
                  
                  if (data.cn < 25 || data.cn > 35) {
                    setShowDialog(true);
                    setMessage('El CN debe estar entre 25 y 35');
                    return;
                  }

                }

                if (active === 1) {
                  let contL = 0;
                  let contM = 0;

                  data.ingredientsSelected.map((item) => {
                    if (item.checked === true) {
                      if (item.cn <= data.cn) {
                        contL++;
                      } else {
                        contM++;
                      }
                    }
                  });

                  if (contL === 0 || contM === 0) {
                    setShowDialog(true);
                    setMessage('Por favor seleccione al menos un ingrediente de cada grupo');
                    return;
                  }
                }

                pushData(active + 1);

                onNext();
              }}
            >
              <Dialog
                isVisible={showDialog}
                onBackdropPress={() => setShowDialog(false)}
              >
                <Dialog.Title title="Error" />
                <Text>{message}</Text>
              </Dialog>
              <Text style={[{ color: 'white' }, buttonTextStyle]}>
                Siguiente
              </Text>
            </TouchableOpacity>
          )}
          {content.length - 1 === active && (
            <TouchableOpacity
              style={[
                {
                  padding: 10,
                  borderRadius: 4,
                  backgroundColor: '#1976d2',
                  alignSelf: 'flex-start',
                },
                buttonStyle,
              ]}
              onPress={() => onFinish()}
            >
              <Text style={[{ color: 'white' }, buttonTextStyle]}>
                Finalizar
              </Text>
            </TouchableOpacity>
          )}
        </View>
      )}
    </View>
  );
};
Stepper.prototype = {
  active: PropTypes.number.isRequired,
  data: PropTypes.object.isRequired,
  content: PropTypes.arrayOf(ReactElement),
  onNext: PropTypes.func.isRequired,
  onBack: PropTypes.func.isRequired,
  onFinish: PropTypes.func.isRequired,
  i18n: PropTypes.object,
  icons: PropTypes.object,
  wrapperStyle: PropTypes.object,
  stepStyle: PropTypes.object,
  stepLine: PropTypes.object,
  stepTextStyle: PropTypes.object,
  buttonStyle: PropTypes.object,
  buttonTextStyle: PropTypes.object,
  showButton: PropTypes.bool,
  pendingState: PropTypes.bool,
  stepsIcons: PropTypes.object
}

export default Stepper;